pro nis_c_gain, seq_in, seq_out, verbose
; SUB-PROGRAM of nis_proc
;
; ABSTRACT
; Goes through sequence of NIS data spectra and corrects for detector 
;    gain. Only Gain 10 Ge channels (and noise) are corrected.
;
; INPUTS
; seq_in -     dark corrected nis sequence
; sourcedir -     source directory for NISCAL programs and data
; verbose -     Toggle description of events std output.
;
; OUTPUTS
; seq_out -    sequence with gain correction, if needed
;
; USES
; eprop_div -     for error propagation
;
; HISTORY
; Created  01/26/98 by N. R. Izenberg as part of niscal version 1.4
; Modified 07/15/98 (NRI) v2.0 compliant - CNFF format
;       09/08/99 (NRI) v3.5 Correct for In-space Gain values 
;       07/20/01 (NRI) v5.0 Compliant (mainly CNISF 5.0)
; 
; NOTES
; From NIS sequence data:    
; IDL columns 1 and 2 define MET high and low word
; CNISF 5.0 column 9 = shutter in/out (0 = in)
; CNISF 5.0 Data is 131:194 for Calibration
; CNISF 5.0 Data is 195:258 for Noise
; IDL coulmn 7 - Gain setting '0'=1, '1'=10
; Gain offset = 9.93+/-0.0282 ON GROUND
; Gain offset = 9.843+/-0.030 IN SPACE
;------------------------------------------------------------------------------
; Main

; if gain is 1, change crosstalk correction to ~1/10th original
; (original figures calculated for gain 10)
;--------------------------------------------------------------
seq_out=seq_in
seq_in2=seq_in
err_in=seq_in(195:258,*)

sz=size(seq_in)
if sz(0) eq 1 then sz(2)=1
for ss=0,sz(2)-1 do begin

if seq_in(7,0) ne 0 then begin

    seq_out(131:162,ss)=(seq_out(131:162,ss))/9.843
    ; watch for zero data
    seq_in2(131:162,ss)=seq_in(131:162,ss)+0.000001*(seq_in(131:162,ss) eq 0)
    seq_out(195:226,ss)=eprop_div(seq_in2(131:162,ss),9.843,err_in(0:31,ss),0.030)
endif    
endfor
if verbose eq 1 then begin
    if seq_in(7,0) ne 0 then begin 
        print,"    >>>> Ge gain set at 10, correct to gain 1" 
        print,'  STEP 4: gain correction applied'
    endif else print,'  STEP 4: no gain correction needed'
endif
return
end    
